comment

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 17, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Line

func Line(line []byte) (off int, region []byte, ok bool)

Line returns the comment portion of a source line and its byte offset. It understands //, #, --, <!--, /* and block-comment continuation (* ...). Code and string contents are disregarded, including "https://" and quoted stamps.

func Texts

func Texts(src []byte, min int) []string

Texts returns comment bodies of at least min bytes.

Types

This section is empty.

Jump to