Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsBinary ¶
Identifies if buf appears to be a binary file (indicating a NUL byte in the display window).
func KindOf ¶
KindOf classifies a file for the three-layer pipeline. skip is true for unknown binaries that must not be decoded as text.
func LanguageFromPath ¶
LanguageFromPath maps a file extension to a language.
func TextPayload ¶
TextPayload reports whether Unicode / stamp / text-C2PA detectors should run.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.